# Official Pypi Implementation of "SRI-Conv: Symmetric Rotation-Invariant Convolutional Kernel"
*Yuexi Du, Nicha, Dvornek, John Onofrey*
*Yale University*

**This is just an initial DEMO for test use**

version: 0.0.2

### Requirement:
```bash
"scipy>=1.9.1",
"numpy>=1.23.1",
"torch>=1.13.0"
```

### Usage
```python
>>> import SRI_Conv
>>> sri_conv = SRI_Conv.SRI_Conv2d(3, 16, 3)
```
